==> mojave-5.17.1.tgz: package/cookie.js <==
import { safeParseJson } from "./json";
import escapeStringRegexp from "escape-string-regexp";
export function setCookie(key, value, options = {}) {
    document.cookie = formatCookieString(key, value, options);
}
export function formatCookieString(key, value, options = {}) {
    let config = {
        domain: options.domain || false,
        path: options.path || "/",
        secure: options.secure || (window.location.protocol === "https:"),
        sameSite: options.sameSite !== undefined ? options.sameSite : "lax",
    };
    let expireDate = (options.expires instanceof Date)
        ? options.expires
        : new Date((new Date()).getTime() + ((options.expires || 30) * 864e5));
    config.expires = expireDate.toUTCString();
    if (/[^a-z0-9\-_.]/i.test(key)) {
        throw new Error("Invalid cookie name: only A-Z 0-9 -_. allowed.");
    }
    const encodedValue = encodeURIComponent(JSON.stringify(value))
        .replace(/%(23|24|26|2B|3A|3C|3E|3D|2F|3F|40|5B|5D|5E|60|7B|7D|7C)/g, decodeURIComponent);
    const encodedOptions = encodeCookieOptions(config);
    return `${key}=${encodedValue};${encodedOptions}`;
}
export function getCookie(key) {
    const matcher = new RegExp(`; ${escapeStringRegexp(key)}=([^;]+)`);
    const match = matcher.exec(`; ${document.cookie}`);
    return match ? safeParseJson(decodeURIComponent(match[1])) : null;
}
export function removeCookie(key) {
    setCookie(key, "", {
        expires: -1,
    });
}
function encodeCookieOptions(options) {
    const encodedOptions = [];
    for (let optionName in options) {
        const optionValue = options[optionName];
        if (!optionValue) {
            continue;
        }
        const sanitizedOption = (optionValue === true)
            ? optionName
            : `${optionName}=${("" + optionValue).split(";")[0]}`;
        encodedOptions.push(sanitizedOption);
    }
    return encodedOptions.join(" ;");
}

==> mojave-5.20.1.tgz: package/cookie.js <==
import { escapeRegexp } from "./escape";
import { safeParseJson } from "./json";
export function setCookie(key, value, options = {}) {
    document.cookie = formatCookieString(key, value, options);
}
export function formatCookieString(key, value, options = {}) {
    let config = {
        domain: options.domain || false,
        path: options.path || "/",
        secure: options.secure || (window.location.protocol === "https:"),
        sameSite: options.sameSite !== undefined ? options.sameSite : "lax",
    };
    let expireDate = (options.expires instanceof Date)
        ? options.expires
        : new Date((new Date()).getTime() + ((options.expires || 30) * 864e5));
    config.expires = expireDate.toUTCString();
    if (/[^a-z0-9\-_.]/i.test(key)) {
        throw new Error("Invalid cookie name: only A-Z 0-9 -_. allowed.");
    }
    const encodedValue = encodeURIComponent(JSON.stringify(value))
        .replace(/%(23|24|26|2B|3A|3C|3E|3D|2F|3F|40|5B|5D|5E|60|7B|7D|7C)/g, decodeURIComponent);
    const encodedOptions = encodeCookieOptions(config);
    return `${key}=${encodedValue};${encodedOptions}`;
}
export function getCookie(key) {
    const matcher = new RegExp(`; ${escapeRegexp(key)}=([^;]+)`);
    const match = matcher.exec(`; ${document.cookie}`);
    return match ? safeParseJson(decodeURIComponent(match[1])) : null;
}
export function removeCookie(key) {
    setCookie(key, "", {
        expires: -1,
    });
}
function encodeCookieOptions(options) {
    const encodedOptions = [];
    for (let optionName in options) {
        const optionValue = options[optionName];
        if (!optionValue) {
            continue;
        }
        const sanitizedOption = (optionValue === true)
            ? optionName
            : `${optionName}=${("" + optionValue).split(";")[0]}`;
        encodedOptions.push(sanitizedOption);
    }
    return encodedOptions.join(" ;");
}
